@@ -8,7 +8,7 @@ from .containers import deep_get, Simple_Child, Proper_Child
 from .logic import sort_by, resolve_order, toposort
 
 import os
-__info__ = load_yaml(os.path.join(os.path.dirname(os.path.dirname(os.path.abspath(__file__))), '.fig.yaml'))
+__info__ = load_yaml(os.path.join(os.path.dirname(os.path.abspath(__file__)), '.fig.yaml'))
 __author__ = __info__['author']
 __version__ = __info__['version']
 
